@@ -104,14 +104,6 @@ class DistilBertEncoder(BaseEncoder):
 
         return loss
 
-    def to(self, device, available_devices):
-        self._model = self._model.to(self.device)
-
-        if self._head is not None:
-            self._head = self._head.to(self.device)
-
-        return self
-
     def prepare(self, priming_data, training_data=None):
         if self._prepared:
             raise Exception('You can only call "prepare" once for a given encoder.')
