@@ -1,4 +1,6 @@
 import torch
+from lightwood.helpers.torch import LightwoodAutocast
+
 
 # Basically cross entropy loss that does the one hot decoding of the targets inside of it... useful for code-logic reasons to have it setup like this
 class TransformCrossEntropyLoss(torch.nn.Module):
@@ -7,8 +9,9 @@ class TransformCrossEntropyLoss(torch.nn.Module):
         self.cross_entropy_loss = torch.nn.CrossEntropyLoss(**kwargs)
 
     def forward(self, preds, target):
-        cat_labels = target.max(1).indices
-        return self.cross_entropy_loss(preds, cat_labels)
+        with LightwoodAutocast():
+            cat_labels = target.max(1).indices
+            return self.cross_entropy_loss(preds, cat_labels)
 
     def estimate_confidence(self, preds, maximum_confidence=None):
         confidences = []
